==> 0.4.39.tar.gz: lib/interfaces/auth/auth.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/foundation.dart';
import 'package:wowit/common.dart';
import 'package:wowit/interfaces/auth/mixins/fake_login_mixin.dart';
import 'package:wowit/interfaces/auth/mixins/firebase_otp_mixin.dart';
import 'package:wowit/interfaces/auth/mixins/sql_login_mixin.dart';
import 'package:wowit/interfaces/mixins/handle_exception_mixin.dart';
import 'package:wowit/models/base_user_model.dart';
import 'mixins/cached_login_mixin.dart';
import 'mixins/firebase_login_mixin.dart';

abstract class PhoneAuth extends BaseAuth
    with
        SQLLoginMixin,
        FirebaseLoginMixin,
        FirebaseOTPMixin,
        HandleExceptionOTPMixin {
  @override
  void handelException(e, {String? subTitle}) {
    super.handelException(e, subTitle: subTitle);
    if (e.toString().contains('firebase_auth')) {
      handleExceptionOTP(e);
    }
  }
}

abstract class BaseAuth with HandleExceptionMixin {
  Future<BaseUserModel?> login() async {
    BaseUserModel? sqlUser;
    String uidPhone = '';
    String phone = '';
    if (this is CachedLoginMixin) {
      Map<String, String>? map =
          await (this as CachedLoginMixin).loadCachedLogin();
      if (map == null) {
        if (kDebugMode) {
          print('$runtimeType.loadCachedLogin failed');
        }
      }
      phone = map?[CachedLoginMixin.phoneKey] ?? '';
      uidPhone = map?[CachedLoginMixin.uidPhoneKey] ?? '';
    }
    if (this is FirebaseLoginMixin) {
      User? firebaseUser = await (this as FirebaseLoginMixin).loginFirebase();
      if (firebaseUser == null) {
        if (kDebugMode) {
          print('$runtimeType.loginFirebase failed');
        }
      }
      uidPhone = firebaseUser?.uid ?? '';
      phone = firebaseUser?.phoneNumber ?? '';
    }
    if (this is FakeLoginMixin &&
        Common.phoneNumberInput == (this as FakeLoginMixin).fakePhone) {
      phone = (this as FakeLoginMixin).fakePhone;
      uidPhone = (this as FakeLoginMixin).fakeUidPhone;
      if (kDebugMode) {
        print('$runtimeType.fakeLogin with phone: $phone, uidPhone: $uidPhone');
      }
    }
    if (this is SQLLoginMixin) {
      sqlUser = await (this as SQLLoginMixin).loginSQL(
        phone: phone,
        uidPhone: uidPhone,
      );
      if (sqlUser == null) {
        if (kDebugMode) {
          print('$runtimeType loginSQL failed');
        }
      }
    }
    if (sqlUser != null) {
      if (this is CachedLoginMixin) {
        await (this as CachedLoginMixin).saveCachedLogin(
          map: {
            CachedLoginMixin.phoneKey: phone,
            CachedLoginMixin.uidPhoneKey: uidPhone,
          },
        );
      }
    }
    return sqlUser;
  }

  Future logout() async {
    try {
      if (this is FirebaseLoginMixin) {
        await (this as FirebaseLoginMixin).logoutFirebase();
      }
      if (this is SQLLoginMixin) {
        await (this as SQLLoginMixin).logoutSQL();
      }

      if (this is CachedLoginMixin) {
        await (this as CachedLoginMixin).removeCachedLogin();
      }
    } catch (e) {
      handelException(e, subTitle: 'logout');
    }
  }
}

==> 0.4.85.tar.gz: lib/interfaces/auth/auth.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/foundation.dart';
import 'package:wowit/common.dart';
import 'package:wowit/interfaces/auth/mixins/fake_login_mixin.dart';
import 'package:wowit/interfaces/auth/mixins/firebase_otp_mixin.dart';
import 'package:wowit/interfaces/auth/mixins/sql_login_mixin.dart';
import 'package:wowit/interfaces/mixins/handle_exception_mixin.dart';
import 'package:wowit/models/base_user_model.dart';
import 'mixins/cached_login_mixin.dart';
import 'mixins/firebase_login_mixin.dart';

abstract class PhoneAuth extends BaseAuth
    with
        SQLLoginMixin,
        FirebaseLoginMixin,
        FirebaseOTPMixin,
        HandleExceptionOTPMixin {
  @override
  void handelException(e, {String? subTitle}) {
    super.handelException(e, subTitle: subTitle);
    if (e.toString().contains('firebase_auth')) {
      handleExceptionOTP(e);
    }
  }
}

abstract class BaseAuth with HandleExceptionMixin {
  Future<BaseUserModel?> login() async {
    BaseUserModel? sqlUser;
    String uidPhone = '';
    String phone = '';
    if (this is CachedLoginMixin) {
      Map<String, String>? map =
          await (this as CachedLoginMixin).loadCachedLogin();
      if (map == null) {
        if (kDebugMode) {
          print('$runtimeType.loadCachedLogin failed');
        }
      }
      phone = map?[CachedLoginMixin.phoneKey] ?? phone;
      uidPhone = map?[CachedLoginMixin.uidPhoneKey] ?? uidPhone;
    }
    if (this is FirebaseLoginMixin) {
      User? firebaseUser = await (this as FirebaseLoginMixin).loginFirebase();
      if (firebaseUser == null) {
        if (kDebugMode) {
          print('$runtimeType.loginFirebase failed');
        }
      }
      phone = firebaseUser?.phoneNumber ?? phone;
      uidPhone = firebaseUser?.uid ?? uidPhone;
    }
    if (this is FakeLoginMixin &&
        (this as FakeLoginMixin).fakePhones.contains(Common.phoneNumberInput)) {
      phone = Common.phoneNumberInput;
      uidPhone = (this as FakeLoginMixin).fakeUidPhone;
      if (kDebugMode) {
        print('$runtimeType.fakeLogin with phone: $phone, uidPhone: $uidPhone');
      }
    }
    if (this is SQLLoginMixin) {
      sqlUser = await (this as SQLLoginMixin).loginSQL(
        phone: phone,
        uidPhone: uidPhone,
      );
      if (sqlUser == null) {
        if (kDebugMode) {
          print('$runtimeType loginSQL failed');
        }
      }
    }
    if (sqlUser != null) {
      if (this is CachedLoginMixin) {
        await (this as CachedLoginMixin).saveCachedLogin(
          map: {
            CachedLoginMixin.phoneKey: phone,
            CachedLoginMixin.uidPhoneKey: uidPhone,
          },
        );
      }
    }
    return sqlUser;
  }

  Future logout() async {
    try {
      if (this is FirebaseLoginMixin) {
        await (this as FirebaseLoginMixin).logoutFirebase();
      }
      if (this is SQLLoginMixin) {
        await (this as SQLLoginMixin).logoutSQL();
      }

      if (this is CachedLoginMixin) {
        await (this as CachedLoginMixin).removeCachedLogin();
      }
    } catch (e) {
      handelException(e, subTitle: 'logout');
    }
  }
}
